## Newspaper readership

### Description

Data from a sample for 580 newspaper readers indicating which newspaper they read most frequently (USA today or Wall Street Journal) and their level of income (Low income vs. High income).

### Variables

A data frame with 580 observations on 3 variables

- id = Respondent identifier
- Income = A factor indicating if a respondent has High or Low income. Factor was created using a median split on income data
- Newspaper = A factor indicating the primary newspaper the respondent reads (USA today or Wall Street Journal)